@@ -751,7 +751,7 @@ class IdeCLI(click.MultiCommand):
 		}[name]
 
 
-@cli.command(cls=IdeCLI)
-def ide():
-	"""Manage an Integrated Development Environment(IDE)"""
-	pass
\ No newline at end of file
+# @cli.command(cls=IdeCLI)
+# def ide():
+# 	"""Manage an Integrated Development Environment(IDE)"""
+# 	pass
\ No newline at end of file
